syntropy package
================

.. automodule:: syntropy
   :members:
   :show-inheritance:
   :undoc-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   syntropy.discrete
   syntropy.gaussian
   syntropy.knn
   syntropy.lattices
   syntropy.neural
   syntropy.mixed
